pub struct ModeRef<'a> { /* private fields */ }Expand description
A handle that allows calling mode methods without keeping the registry read lock held across callback execution.
Implementations
Sourceimpl<'a> ModeRef<'a>
impl<'a> ModeRef<'a>
pub fn on_session_start( &self, session: &Session, env: &Envelope, ) -> Result<ModeResponse, MacpError>
pub fn on_message( &self, session: &Session, env: &Envelope, ) -> Result<ModeResponse, MacpError>